@@ -11,6 +11,7 @@ from typing import Dict, Optional, Union, List
 import pandas as pd
 
 try:
+    # pylint: disable=unused-import
     import opm.io.deck
 except ImportError:
     # Allow parts of ecl2df to work without OPM:
@@ -175,8 +176,11 @@ def deck2dfs(
                 if rec_data["STATUS"] not in ["OPEN", "SHUT", "STOP", "AUTO"]:
                     rec_data["STATUS"] = "SHUT"
                     logger.warning(
-                        "WELOPEN status %s is not a valid "
-                        "COMPDAT state. Using 'SHUT' instead." % rec_data["STATUS"]
+                        (
+                            "WELOPEN status %s is not a valid "
+                            "COMPDAT state. Using 'SHUT' instead."
+                        ),
+                        rec_data["STATUS"],
                     )
                 welopenrecords.append(rec_data)
         elif kword.name == "WELSEGS":
@@ -445,7 +449,7 @@ def applywelopen(compdat_df: pd.DataFrame, welopen_df: pd.DataFrame) -> pd.DataF
     if not compdat_df.empty:
         compdat_df = (
             compdat_df.sort_values(by=["KEYWORD_IDX"])
-            .drop_duplicates(subset=["I", "J", "K1", "K2", "DATE"], keep="last")
+            .drop_duplicates(subset=["WELL", "I", "J", "K1", "K2", "DATE"], keep="last")
             .reset_index(drop=True)
         )
 
