@@ -1,6 +1,5 @@
 """Test module for nnc2df"""
 
-import sys
 from pathlib import Path
 
 import pytest
@@ -95,7 +94,24 @@ WELSPECS
     grupdf.to_csv("gruptreenet.csv", index=False)
     grup_dict = gruptree.edge_dataframe2dict(grupdf)
     print("Copy and paste into RST files:")
-    print(str(gruptree.dict2treelib("", grup_dict[0])))
+    print(str(gruptree.tree_from_dict(grup_dict[0])))
+
+    assert (
+        str(gruptree.tree_from_dict(grup_dict[0])).strip()
+        == """
+NORTHSEA
+└── AREA
+    └── FIELD
+        ├── OP
+        │   ├── OPEAST
+        │   │   └── OP2
+        │   └── OPWEST
+        │       └── OP1
+        └── WI
+            └── INJEAST
+                └── INJ1
+    """.strip()
+    )
 
 
 def test_grupnetdf():
@@ -123,6 +139,60 @@ GRUPNET
     assert 100 in grupdf["TERMINAL_PRESSURE"].values
 
 
+@pytest.mark.parametrize(
+    "dicttree, expected_str",
+    [
+        ({}, ""),
+        ({"foo": {}}, "foo"),
+        ({"foo": {"bar": {}}}, "foo\n└── bar"),
+        ({"foo": {"bar": {}, "com": {}}}, "foo\n├── bar\n└── com"),
+        # Test sorting:
+        ({"foo": {"com": {}, "bar": {}}}, "foo\n├── bar\n└── com"),
+        # Two levels:
+        (
+            {"foo": {"bar": {}, "com": {"fjooo": {}}}},
+            """
+foo
+├── bar
+└── com
+    └── fjooo""",
+        ),
+        # Integers as node names:
+        ({1: {2: {}}}, "1\n└── 2"),
+        # More complex structure:
+        # Note: Node names cannot be duplicated, even on
+        # unique branches:
+        (
+            {
+                "foo": {
+                    "bar": {},
+                    "com": {"fjooo": {}},
+                    "bart": {},
+                    "comt": {"fjooot": {}},
+                }
+            },
+            """
+foo
+├── bar
+├── bart
+├── com
+│   └── fjooo
+└── comt
+    └── fjooot
+            """,
+        ),
+    ],
+)
+def test_tree_from_dict(dicttree, expected_str):
+    assert str(gruptree.tree_from_dict(dicttree)).strip() == expected_str.strip()
+
+
+def test_dict2treelib_deprecated():
+    """dict2treelib is deprecated and replaced by tree_from_dict()"""
+    with pytest.warns(FutureWarning):
+        gruptree.dict2treelib("foo", {"bar": {}})
+
+
 @pytest.mark.parametrize(
     "schstr, expected_dframe, expected_tree",
     [
@@ -144,8 +214,8 @@ GRUPNET
                 ]
             ),
             """
-└── FIELD
-    └── OP
+FIELD
+└── OP
 """,
         ),
         # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -168,8 +238,8 @@ GRUPNET
                 ]
             ),
             """
-└── FIELDA
-    └── OP
+FIELDA
+└── OP
 """,
         ),
         # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -195,10 +265,10 @@ GRUPNET
                 ]
             ),
             """
-├── FIELDA
-│   └── OP
-└── FIELDB
-    └── OPX
+FIELDA
+└── OP
+FIELDB
+└── OPX
 """,
         )
         # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -217,12 +287,54 @@ def test_grupnetroot(schstr, expected_dframe, expected_tree):
         expected_dframe.sort_values(["CHILD", "PARENT"]).reset_index(drop=True),
         check_dtype=False,
     )
-    gruptreedict = gruptree.edge_dataframe2dict(grupdf)
-    treelibtree = gruptree.dict2treelib("", gruptreedict[0])
-    assert str(treelibtree).strip() == expected_tree.strip()
+    treelist = gruptree.edge_dataframe2dict(grupdf)
+    # Merge strings for all trees (if multiple roots)
+    strtrees = [str(gruptree.tree_from_dict(tree)) for tree in treelist]
+    strtrees.sort()  # Avoid flaky test due to sorting
+    treelibtree = "".join(strtrees)
+    assert treelibtree.strip() == expected_tree.strip()
 
 
-def test_emptytree():
+def test_multiple_roots():
+    """Test edge_dataframe2dict with multiple roots"""
+    answer = [
+        {"FIELDA": {"PLATA": {}}},
+        {"FIELDB": {"PLATB": {}}},
+    ]
+    edges = pd.DataFrame(
+        [
+            {"CHILD": "FIELDA", "PARENT": None},
+            {"CHILD": "FIELDB", "PARENT": None},
+            {"CHILD": "PLATA", "PARENT": "FIELDA"},
+            {"CHILD": "PLATB", "PARENT": "FIELDB"},
+        ]
+    )
+    assert gruptree.edge_dataframe2dict(edges) == answer
+
+    # Same result if the dummy rows for the roots are omitted:
+    edges_noroots = pd.DataFrame(
+        [
+            {"CHILD": "PLATA", "PARENT": "FIELDA"},
+            {"CHILD": "PLATB", "PARENT": "FIELDB"},
+        ]
+    )
+    assert gruptree.edge_dataframe2dict(edges_noroots) == answer
+
+    # And order does not matter, should be sorted on root node label:
+    edges_noroots = pd.DataFrame(
+        [
+            {"CHILD": "PLATB", "PARENT": "FIELDB"},
+            {"CHILD": "PLATA", "PARENT": "FIELDA"},
+        ]
+    )
+    assert gruptree.edge_dataframe2dict(edges_noroots) == answer
+
+    # The function tree_from_dict should be called with one tree at a time:
+    with pytest.raises(ValueError, match="single tree"):
+        gruptree.tree_from_dict({"foo": 1, "bar": 2})
+
+
+def test_emptytree_strdeck():
     """Test empty schedule sections. Don't want to crash"""
     schstr = ""
     deck = EclFiles.str2deck(schstr)
@@ -230,9 +342,19 @@ def test_emptytree():
     assert grupdf.empty
     gruptreedict = gruptree.edge_dataframe2dict(grupdf)
     assert not gruptreedict[0]
-    treelibtree = gruptree.dict2treelib("", gruptreedict[0])
-    treestring = str(treelibtree)
-    assert not treestring.strip()  # Let it return whitespace
+
+    treelibtree = gruptree.tree_from_dict(gruptreedict[0])
+    # Returning an empty string and not a treelib.Tree() is
+    # a workaround for a limitation in treelib.
+    assert treelibtree == ""
+
+
+def test_emptytree_commandlinetool(tmpdir, mocker, caplog):
+    tmpdir.chdir()
+    Path("EMPTY.DATA").write_text("")
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", "--prettyprint", "EMPTY.DATA"])
+    ecl2csv.main()
+    assert "No tree data to prettyprint" in caplog.text
 
 
 def test_tstep():
@@ -259,10 +381,10 @@ WELSPECS
     print(grupdf)
 
 
-def test_main(tmpdir):
+def test_main(tmpdir, mocker):
     """Test command line interface"""
     tmpcsvfile = tmpdir.join("gruptree.csv")
-    sys.argv = ["ecl2csv", "gruptree", DATAFILE, "-o", str(tmpcsvfile)]
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", DATAFILE, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -270,16 +392,77 @@ def test_main(tmpdir):
     assert not disk_df.empty
 
 
-def test_prettyprint():
+def test_prettyprint(mocker, capsys):
     """Test pretty printing via command line interface"""
-    sys.argv = ["ecl2csv", "gruptree", DATAFILE, "--prettyprint"]
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", DATAFILE, "--prettyprint"])
     ecl2csv.main()
+    stdout = capsys.readouterr().out.strip()
+    print(stdout)
+    assert (
+        """
+Date: 2000-01-01
+FIELD
+├── OP
+└── WI
 
 
-def test_main_subparser(tmpdir):
+Date: 2000-02-01
+FIELD
+├── OP
+│   ├── OP_1
+│   ├── OP_2
+│   └── OP_3
+└── WI
+    └── WI_1
+
+
+Date: 2000-06-01
+FIELD
+├── OP
+│   ├── OP_1
+│   ├── OP_2
+│   └── OP_3
+└── WI
+    ├── WI_1
+    └── WI_2
+
+
+Date: 2001-01-01
+FIELD
+├── OP
+│   ├── OP_1
+│   ├── OP_2
+│   ├── OP_3
+│   ├── OP_4
+│   └── OP_5
+└── WI
+    ├── WI_1
+    └── WI_2
+
+
+Date: 2001-03-01
+FIELD
+├── OP
+│   ├── OP_1
+│   ├── OP_2
+│   ├── OP_3
+│   ├── OP_4
+│   └── OP_5
+└── WI
+    ├── WI_1
+    ├── WI_2
+    └── WI_3
+""".strip()
+        in stdout
+    )
+
+
+def test_main_subparser(tmpdir, mocker):
     """Test command line interface"""
     tmpcsvfile = tmpdir.join("gruptree.csv")
-    sys.argv = ["ecl2csv", "gruptree", "-v", DATAFILE, "-o", str(tmpcsvfile)]
+    mocker.patch(
+        "sys.argv", ["ecl2csv", "gruptree", "-v", DATAFILE, "-o", str(tmpcsvfile)]
+    )
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
