@@ -1,6 +1,7 @@
 import os
 import sys
 import datetime
+from datetime import datetime as dt
 import logging
 from pathlib import Path
 
@@ -20,6 +21,8 @@ from ecl2df.summary import (
     df,
     smry_meta,
     _fix_dframe_for_libecl,
+    _fallback_date_roll,
+    date_range,
 )
 
 TESTDIR = Path(__file__).absolute().parent
@@ -82,7 +85,7 @@ def test_df_column_keys():
     assert set(sumdf.attrs["meta"].keys()) == {"FOPT", "FOPR"}
 
 
-def test_summary2df_dates(caplog):
+def test_summary2df_dates():
     """Test that we have some API possibilities with ISO dates"""
     eclfiles = EclFiles(DATAFILE)
 
@@ -294,14 +297,19 @@ def test_foreseeable_future(tmpdir):
     assert (
         dframe.index
         == [
-            datetime.datetime(2000, 1, 1),
+            dt(2000, 1, 1),
             # This discrepancy is due to seconds as a 32-bit float
             # having an accuracy limit (roundoff-error)
             # https://github.com/equinor/ecl/issues/803
-            datetime.datetime(2499, 12, 31, 23, 55, 44),
+            dt(2499, 12, 31, 23, 55, 44),
         ]
     ).all()
 
+    # Try with time interpolation involved:
+    dframe = summary.df(eclsum, time_index="yearly")
+    assert len(dframe) == 501
+    assert dframe.index.max() == datetime.date(year=2500, month=1, day=1)
+
     # Try with one-year timesteps:
     src_dframe = pd.DataFrame(
         {
@@ -312,7 +320,7 @@ def test_foreseeable_future(tmpdir):
     eclsum = df2eclsum(src_dframe, casename="PLUGABANDON")
     dframe = summary.df(eclsum)
     # Still buggy:
-    assert dframe.index[-1] == datetime.datetime(2068, 12, 31, 23, 57, 52)
+    assert dframe.index[-1] == dt(2068, 12, 31, 23, 57, 52)
 
     # Try with one-year timesteps, starting late:
     src_dframe = pd.DataFrame(
@@ -324,7 +332,156 @@ def test_foreseeable_future(tmpdir):
     eclsum = df2eclsum(src_dframe, casename="PLUGABANDON")
     dframe = summary.df(eclsum)
     # Works fine when stepping only 68 years:
-    assert dframe.index[-1] == datetime.datetime(2468, 1, 1, 0, 0, 0)
+    assert dframe.index[-1] == dt(2468, 1, 1, 0, 0, 0)
+
+
+@pytest.mark.parametrize(
+    "rollme, direction, freq, expected",
+    [
+        (
+            dt(3000, 1, 1),
+            "forward",
+            "yearly",
+            dt(3000, 1, 1),
+        ),
+        (
+            dt(3000, 1, 1),
+            "forward",
+            "monthly",
+            dt(3000, 1, 1),
+        ),
+        (
+            dt(3000, 1, 2),
+            "forward",
+            "yearly",
+            dt(3001, 1, 1),
+        ),
+        (
+            dt(3000, 1, 2),
+            "forward",
+            "monthly",
+            dt(3000, 2, 1),
+        ),
+        (
+            dt(3000, 1, 1),
+            "back",
+            "yearly",
+            dt(3000, 1, 1),
+        ),
+        (
+            dt(3000, 1, 1),
+            "back",
+            "monthly",
+            dt(3000, 1, 1),
+        ),
+        (
+            dt(3000, 12, 31),
+            "back",
+            "yearly",
+            dt(3000, 1, 1),
+        ),
+        (
+            dt(3000, 2, 2),
+            "back",
+            "monthly",
+            dt(3000, 2, 1),
+        ),
+        pytest.param(
+            dt(3000, 2, 2),
+            "forward",
+            "daily",
+            None,
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+        pytest.param(
+            dt(3000, 2, 2),
+            "upwards",
+            "yearly",
+            None,
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+    ],
+)
+def test_fallback_date_roll(rollme, direction, freq, expected):
+    assert _fallback_date_roll(rollme, direction, freq) == expected
+
+
+@pytest.mark.parametrize(
+    "start, end, freq, expected",
+    [
+        (
+            dt(3000, 1, 1),
+            dt(3002, 1, 1),
+            "yearly",
+            [
+                dt(3000, 1, 1),
+                dt(3001, 1, 1),
+                dt(3002, 1, 1),
+            ],
+        ),
+        (
+            dt(2999, 11, 1),
+            dt(3000, 2, 1),
+            "monthly",
+            [
+                dt(2999, 11, 1),
+                dt(2999, 12, 1),
+                dt(3000, 1, 1),
+                dt(3000, 2, 1),
+            ],
+        ),
+        pytest.param(
+            dt(3000, 1, 1),
+            dt(3000, 2, 1),
+            "weekly",
+            None,
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+        (
+            # Crossing the problematic time boundary:
+            dt(2260, 1, 1),
+            dt(2263, 1, 1),
+            "yearly",
+            [
+                dt(2260, 1, 1),
+                dt(2261, 1, 1),
+                dt(2262, 1, 1),
+                dt(2263, 1, 1),
+            ],
+        ),
+        (
+            dt(3000, 1, 1),
+            dt(3000, 1, 1),
+            "yearly",
+            [
+                dt(3000, 1, 1),
+            ],
+        ),
+        (
+            dt(2000, 1, 1),
+            dt(2000, 1, 1),
+            "yearly",
+            [
+                dt(2000, 1, 1),
+            ],
+        ),
+        (
+            dt(2000, 1, 1),
+            dt(1000, 1, 1),
+            "yearly",
+            [],
+        ),
+        (
+            dt(3000, 1, 1),
+            dt(2000, 1, 1),
+            "yearly",
+            [],
+        ),
+    ],
+)
+def test_date_range(start, end, freq, expected):
+    # When dates are beyond year 2262, the function _fallback_date_range() is triggered.
+    assert date_range(start, end, freq) == expected
 
 
 def test_resample_smry_dates():
@@ -347,14 +504,12 @@ def test_resample_smry_dates():
     weekly = resample_smry_dates(ecldates, freq="weekly")
     assert len(weekly) == 159
 
-    assert resample_smry_dates(ecldates, freq="2001-04-05") == [
-        datetime.datetime(2001, 4, 5, 0, 0)
-    ]
+    assert resample_smry_dates(ecldates, freq="2001-04-05") == [dt(2001, 4, 5, 0, 0)]
     assert resample_smry_dates(ecldates, freq=datetime.date(2001, 4, 5)) == [
         datetime.date(2001, 4, 5)
     ]
-    assert resample_smry_dates(ecldates, freq=datetime.datetime(2001, 4, 5, 0, 0)) == [
-        datetime.datetime(2001, 4, 5, 0, 0)
+    assert resample_smry_dates(ecldates, freq=dt(2001, 4, 5, 0, 0)) == [
+        dt(2001, 4, 5, 0, 0)
     ]
     # start and end should be included:
     assert (
@@ -507,39 +662,33 @@ def test_smry_meta_synthetic():
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             pd.DataFrame([{"DATE": "2516-01-01", "FOPT": 1}]),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2516, 1, 1)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2516, 1, 1)]).rename_axis("DATE"),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             pd.DataFrame([{"DATE": np.datetime64("2016-01-01"), "FOPT": 1}]),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2016, 1, 1)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2016, 1, 1)]).rename_axis("DATE"),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             pd.DataFrame(
                 [{"DATE": pd.Timestamp(datetime.date(2016, 1, 1)), "FOPT": 1}]
             ),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2016, 1, 1)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2016, 1, 1)]).rename_axis("DATE"),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             pd.DataFrame(
                 [
                     {
-                        "DATE": datetime.datetime(2016, 1, 1, 12, 34, 56),
+                        "DATE": dt(2016, 1, 1, 12, 34, 56),
                         "FOPT": 1,
                     }
                 ]
             ),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2016, 1, 1, 12, 34, 56)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2016, 1, 1, 12, 34, 56)]).rename_axis(
+                "DATE"
+            ),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
@@ -551,17 +700,13 @@ def test_smry_meta_synthetic():
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             pd.DataFrame([{"DATE": datetime.date(2017, 1, 1), "FOPT": 1}]),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2017, 1, 1)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2017, 1, 1)]).rename_axis("DATE"),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
             # Dates that go beyond Pandas' datetime64[ns] limits:
             pd.DataFrame([{"DATE": datetime.date(2517, 1, 1), "FOPT": 1}]),
-            pd.DataFrame(
-                [{"FOPT": 1}], index=[datetime.datetime(2517, 1, 1)]
-            ).rename_axis("DATE"),
+            pd.DataFrame([{"FOPT": 1}], index=[dt(2517, 1, 1)]).rename_axis("DATE"),
         ),
         # # # # # # # # # # # # # # # # # # # # # # # #
         (
